Version_0.5.1

# Clustergrammer-Widget2 0.5.1¶

In [1]:

    import numpy as np
    import pandas as pd
    import clustergrammer_widget2
    from clustergrammer import *
    net = Network()

In [2]:

    net.load_file('rc_two_cats.txt')
    net.cluster()
    df = net.export_df()

In [3]:

    net.load_df(df)
    net.cluster()
    net_json = net.export_viz_to_widget()

In [4]:

    w = clustergrammer_widget2.ExampleWidget(network=net_json)
    w

In [ ]: